import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * A car class which shoots at an Enemy or Person Class.
 * 
 * @author Revernd
 */
public class Car  extends Actor
{
    private int shotTimer = 0;
    private HealthCollection hc;
    
    public Car(World road)
    {
        this.hc = new HealthCollection(road);
        this.setRotation(-90);
    }

    /**
     * Act - do whatever the Ship wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        carShot();
        carDrive();
        runOver();
    }
    
    public void carShot()
    {
        if (shotTimer > 0) {
            shotTimer = shotTimer - 1;
        }
        else if (Greenfoot.isKeyDown("space")) {
            Greenfoot.playSound("Gun_Silencer.wav");
            getWorld().addObject(new Shot(this), getX(), getY());
            shotTimer = 20; // delay next shot
        }
    }
        
    public void runOver()
    {
        Actor peep = getOneObjectAtOffset(0, 0, Person.class);
        Actor bonus = getOneObjectAtOffset(0, 0, Bonus.class);
        
        if ( peep != null )
        {   
            Road road = (Road) this.getWorld();
            road.removeObject(peep);
            
            Counter bodiesSaved = road.getBodiesSaved(); 
            Counter gameScore = road.getScore();
            
            bodiesSaved.bumpCount("Saved: ", 1);
            gameScore.bumpCount("Score: ", 7);
            
            Greenfoot.playSound("bulletbody.wav");
        }
        
        if ( bonus != null )
        {
            Road road = (Road) this.getWorld();
            road.removeObject(bonus);
            this.addHealth();
        }
    }
    
    public void carDrive()
    {
        if ( Greenfoot.isKeyDown("up") )
        {
            move(4);
            keyCheck(5);
        }
        if ( Greenfoot.isKeyDown("down") ) 
        {
            move(-4);
            keyCheck(3);
        }
    }
    
    public void addHealth()
    {
        this.hc.addHealth();
    }
    
    public void removeHealth()
    {
        this.hc.removeHealth();
    }
    
    public int getHealth()
    {
        return this.hc.getHealth();
    }
    
    private void keyCheck(int x)
    {
        if ( Greenfoot.isKeyDown("left") ) 
        {
            turn(-(x));
        }
        if ( Greenfoot.isKeyDown("right") )
        {
            turn(x);
        }
    }
}
