import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * A bullet to be shot at spiders (enemy class).
 * 
 * A bullet that will expire on the edges of the world. If it hits an (Enemy.class)
 * on the way, it destroys the Spider (Enemy), and then expires immediately.
 */
public class Shot  extends Actor
{
    private Car myCar;
    private int carDegrees;

    public Shot(Car myCar)
    {
        this.myCar = myCar;
        this.carDegrees = myCar.getRotation();
        turn(this.carDegrees);
    }

    /**
     * Act - do whatever the Shot wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        int ypos = getY();
        int xpos = getX();
        if ( ypos > 0 && ypos < getWorld().getHeight() - 1 && xpos > 0 && xpos < getWorld().getWidth() -1 ) 
        {
            Actor enemy = getOneIntersectingObject(Enemy.class);
            Actor peep = getOneIntersectingObject(Person.class);
            
            move(10);
            
            if ( enemy != null ) 
            {
                hitAnEnemy();
                this.getWorld().removeObject(enemy);
                this.getWorld().removeObject(this);
            }
            
            if ( peep != null )
            {
                hitAPerson();
                this.getWorld().removeObject(peep);
                this.getWorld().removeObject(this);
            }
        }
        else 
        {
            // I reached the edge of the screen
            getWorld().removeObject(this);
        }
    }
    
    /**
     * This method gets called (from the act method, above) when the shot hits an
     * Enemy or Person class. It needs to do only one thing: increase the score counter (or decrees if Person).
     */
    private void hitAnEnemy()
    {
        Road road = (Road) this.getWorld();
        Counter gameScore = road.getScore();
        gameScore.bumpCount("Score: ", 3);
    }
    
    private void hitAPerson()
    {
        Road road = (Road) this.getWorld();
        Counter gameScore = road.getScore();
        gameScore.bumpCount("Score: ", -1);
    }
}
